@@ -1,18 +1,19 @@
 # encoding:UTF-8
 import ctypes
 
-from .cinterface import IS_V3
-from .constants import FieldType
-from .error import *
-from .precision import *
+from taos.cinterface import IS_V3
+from taos.constants import FieldType
+from taos.precision import PrecisionEnum, PrecisionError
 from datetime import datetime
 from ctypes import *
 import sys
 
 _datetime_epoch = datetime.utcfromtimestamp(0)
 
+
 def _is_not_none(obj):
-    return obj != None
+    return obj is not None
+
 
 class TaosBind(ctypes.Structure):
     _fields_ = [
@@ -192,7 +193,6 @@ class TaosBind(ctypes.Structure):
         else:
             self.buffer = cast(pointer(c_uint32(value)), c_void_p)
             self.buffer_length = sizeof(c_uint32)
-        
 
     def bigint_unsigned(self, value):
         self.buffer_type = FieldType.C_BIGINT_UNSIGNED
@@ -375,7 +375,7 @@ class TaosMultiBind(ctypes.Structure):
         self.num = len(values)
         is_null = [1 if v is None else 0 for v in values]
         self.is_null = cast((c_byte * self.num)(*is_null), c_char_p)
-        
+
         if sum(is_null) == self.num:
             self.length = (c_int32 * len(values))(0 * self.num)
             return
@@ -406,7 +406,7 @@ class TaosMultiBind(ctypes.Structure):
             )
         self.length = (c_int32 * len(values))(*[len(b) if b is not None else 0 for b in _bytes])
         self.buffer_length = buffer_length
-        
+
     def binary(self, values):
         if type(values) is not tuple and type(values) is not list:
             values = tuple([values])
