@@ -11,8 +11,8 @@ try:
 except BaseException:
     pass
 
-from .error import *
-from .schemaless import *
+from taos.error import *
+from taos.schemaless import *
 
 _UNSUPPORTED = {}
 
@@ -34,7 +34,9 @@ def _load_taos_linux():
 
 
 def _load_taos_darwin():
-    return ctypes.CDLL("libtaos.dylib")
+    from ctypes.macholib.dyld import dyld_find as _dyld_find
+
+    return ctypes.CDLL(_dyld_find("libtaos.dylib"))
 
 
 def _load_taos_windows():
@@ -70,13 +72,13 @@ def taos_get_client_info():
 IS_V3 = False
 
 if taos_get_client_info().split(".")[0] < "3":
-    from .field import CONVERT_FUNC, CONVERT_FUNC_BLOCK, TaosFields, TaosField, set_tz
+    from taos.field import CONVERT_FUNC, CONVERT_FUNC_BLOCK, TaosFields, TaosField, set_tz
 else:
-    from .field import CONVERT_FUNC, CONVERT_FUNC_BLOCK, TaosFields, TaosField, set_tz
+    from taos.field import CONVERT_FUNC, CONVERT_FUNC_BLOCK, TaosFields, TaosField, set_tz
 
     # use _v3s TaosField overwrite _v2s here, dont change import order
-    from .field_v3 import CONVERT_FUNC_BLOCK_v3, TaosFields, TaosField
-    from .constants import FieldType
+    from taos.field_v3 import CONVERT_FUNC_BLOCK_v3, TaosFields, TaosField
+    from taos.constants import FieldType
 
     IS_V3 = True
 
@@ -323,7 +325,7 @@ def taos_fetch_rows_a(result, callback, param):
 
 def taos_affected_rows(result):
     # type: (c_void_p) -> c_int
-    """The affected rows after runing query"""
+    """The affected rows after running query"""
     return _libtaos.taos_affected_rows(result)
 
 
@@ -947,24 +949,28 @@ def taos_schemaless_insert(connection, lines, protocol, precision):
     taos_free_result(res)
     return affected_rows
 
+
 try:
     _libtaos.tmq_conf_new.restype = c_void_p
 except Exception as err:
     _UNSUPPORTED["tmq_conf_new"] = err
-    
+
+
 def tmq_conf_new():
     # type: () -> c_void_p
     _check_if_supported()
     return c_void_p(_libtaos.tmq_conf_new())
 
+
 try:
     _libtaos.tmq_conf_set.restype = c_int
     _libtaos.tmq_conf_set.argtypes = (c_void_p, c_char_p, c_char_p)
 except Exception as err:
-    _UNSUPPORTED["tmq_conf_set"] = err 
+    _UNSUPPORTED["tmq_conf_set"] = err
+
 
 def tmq_conf_set(conf, key, value):
-    # type: (c_void_p, c_char_p, c_char_p) -> None
+    # type: (c_void_p, str, str) -> None
     _check_if_supported()
 
     if not isinstance(value, str):
@@ -974,35 +980,42 @@ def tmq_conf_set(conf, key, value):
     if res != 0:
         raise TmqError(msg=f"fail to execute tmq_conf_set({key},{value}), code={res}", errno=res)
 
+
 try:
     _libtaos.tmq_conf_destroy.argtypes = (c_void_p,)
     _libtaos.tmq_conf_destroy.restype = None
 except Exception as err:
     _UNSUPPORTED["tmq_conf_destroy"] = err
 
+
 def tmq_conf_destroy(conf):
     # type (c_void_p,) -> None
     _check_if_supported()
     _libtaos.tmq_conf_destroy(conf)
 
-tmq_commit_cb = CFUNCTYPE(c_void_p, c_int, c_void_p, c_void_p)
+
+tmq_commit_cb = CFUNCTYPE(None, c_void_p, c_int, c_void_p)
+
 try:
     _libtaos.tmq_conf_set_auto_commit_cb.argtypes = (c_void_p, tmq_commit_cb, c_void_p)
     _libtaos.tmq_conf_set_auto_commit_cb.restype = None
 except Exception as err:
     _UNSUPPORTED["tmq_conf_set_auto_commit_cb"] = err
-    
+
+
 def tmq_conf_set_auto_commit_cb(conf, cb, param):
     # type (c_void_p, tmq_commit_cb, c_void_p) -> None
     _check_if_supported()
     _libtaos.tmq_conf_set_auto_commit_cb(conf, tmq_commit_cb(cb), param)
 
-try:    
+
+try:
     _libtaos.tmq_consumer_new.restype = c_void_p
     _libtaos.tmq_consumer_new.argtypes = (c_void_p, c_char_p, c_int)
 except Exception as err:
     _UNSUPPORTED["tmq_consumer_new"] = err
 
+
 def tmq_consumer_new(conf, errstrlen=0):
     # type (c_void_p, c_char_p, c_int) -> c_void_p
     _check_if_supported()
@@ -1012,22 +1025,26 @@ def tmq_consumer_new(conf, errstrlen=0):
         raise TmqError("failed on tmq_consumer_new")
     return tmq
 
+
 try:
     _libtaos.tmq_list_new.restype = c_void_p
 except Exception as err:
     _UNSUPPORTED["tmq_list_new"] = err
 
+
 def tmq_list_new():
     # type () -> c_void_p
     _check_if_supported()
     return c_void_p(_libtaos.tmq_list_new())
 
+
 try:
     _libtaos.tmq_list_append.restype = c_int
     _libtaos.tmq_list_append.argtypes = (c_void_p, c_char_p)
 except Exception as err:
     _UNSUPPORTED["tmq_list_append"] = err
 
+
 def tmq_list_append(list, topic):
     # type (c_void_p, c_char_p) -> None
     _check_if_supported()
@@ -1038,18 +1055,21 @@ def tmq_list_append(list, topic):
     res = _libtaos.tmq_list_append(list, ctypes.c_char_p(topic.encode("utf-8")))
     return res
 
+
 try:
     _libtaos.tmq_list_destroy.restype = None
     _libtaos.tmq_list_destroy.argtypes = (c_void_p,)
 except Exception as err:
     _UNSUPPORTED["tmq_list_destroy"] = err
-    
+
+
 def tmq_list_destroy(list):
     _check_if_supported()
     # type (c_void_p,) -> None
     _libtaos.tmq_list_destroy(list)
 
-try:    
+
+try:
     _libtaos.tmq_list_get_size.restype = c_int
     _libtaos.tmq_list_get_size.argtypes = (c_void_p,)
 except Exception as err:
@@ -1061,6 +1081,7 @@ try:
 except Exception as err:
     _UNSUPPORTED["tmq_list_to_c_array"] = err
 
+
 def tmq_list_to_c_array(list):
     # type (c_void_p,) -> [string]
     _check_if_supported()
@@ -1072,31 +1093,40 @@ def tmq_list_to_c_array(list):
         res.append(c_array[i].decode("utf-8"))
     return res
 
+
 try:
     _libtaos.tmq_subscribe.argtypes = (c_void_p, c_void_p)
     _libtaos.tmq_subscribe.restype = c_int
 except Exception as err:
     _UNSUPPORTED["tmq_subscribe"] = err
 
+
 def tmq_subscribe(tmq, list):
     # type (c_void_p, c_void_p) -> None
     _check_if_supported()
-    res =  _libtaos.tmq_subscribe(tmq, list)
+    res = _libtaos.tmq_subscribe(tmq, list)
     if res != 0:
         raise TmqError(msg="failed on tmq_subscribe()", errno=res)
 
+
 try:
     _libtaos.tmq_unsubscribe.argtypes = (c_void_p,)
     _libtaos.tmq_unsubscribe.restype = c_int
 except Exception as err:
     _UNSUPPORTED["tmq_unsubscribe"] = err
 
+
 def tmq_unsubscribe(tmq):
     # type (c_void_p,) -> None
     _check_if_supported()
     res = _libtaos.tmq_unsubscribe(tmq)
+    if res == -1:
+        # -1 means empty subscription topic list..
+        # tmq_unsubscribe will subscribe a empty topic list to clear the consumer task.
+        return
     if res != 0:
-        raise TmqError(msg="failed on tmq_unsubscribe()", errno=res)
+        raise TmqError(msg=f"failed on tmq_unsubscribe() {res}", errno=res)
+
 
 try:
     _libtaos.tmq_subscription.argtypes = (c_void_p, c_void_p)
@@ -1104,52 +1134,61 @@ try:
 except Exception as err:
     _UNSUPPORTED["tmq_subscription"] = err
 
+
 def tmq_subscription(tmq):
     # type (c_void_p, c_void_p) -> [string]
     _check_if_supported()
     topics = tmq_list_new()
-    res =  _libtaos.tmq_subscription(tmq, byref(topics))
+    res = _libtaos.tmq_subscription(tmq, byref(topics))
     if res != 0:
         raise TmqError(msg="failed on tmq_subscription()", errno=res)
-    res =  tmq_list_to_c_array(topics)
+    res = tmq_list_to_c_array(topics)
     tmq_list_destroy(topics)
-    return res;
-    
+    return res
+
+
 try:
     _libtaos.tmq_consumer_poll.argtypes = (c_void_p, c_int64)
     _libtaos.tmq_consumer_poll.restype = c_void_p
 except Exception as err:
     _UNSUPPORTED["tmq_consumer_poll"] = err
 
+
 def tmq_consumer_poll(tmq, wait_time):
     # type (c_void_p, c_int64) -> c_void_p
     _check_if_supported()
     return c_void_p(_libtaos.tmq_consumer_poll(tmq, wait_time))
 
+
 try:
     _libtaos.tmq_consumer_close.argtypes = (c_void_p,)
     _libtaos.tmq_consumer_close.restype = c_int
 except Exception as err:
     _UNSUPPORTED["tmq_consumer_close"] = err
 
+
 def tmq_consumer_close(tmq):
     # type (c_void_p,) -> None
     _check_if_supported()
-    res =  _libtaos.tmq_consumer_close(tmq)
+    res = _libtaos.tmq_consumer_close(tmq)
     if res != 0:
         raise TmqError(msg="failed on tmq_consumer_close()", errno=res)
+
+
 try:
-    _libtaos.tmq_commit.argtypes = (c_void_p, c_void_p, c_int32)
-    _libtaos.tmq_commit.restype = c_int
+    _libtaos.tmq_commit_sync.argtypes = (c_void_p, c_void_p)
+    _libtaos.tmq_commit_sync.restype = c_int
 except Exception as err:
     _UNSUPPORTED["tmq_commit"] = err
 
-def tmq_commit(tmq, offset, _async):
-    # type (c_void_p, c_void_p, c_int32) -> None
+
+def tmq_commit_sync(tmq, offset):
+    # type: (c_void_p, c_void_p) -> None
     _check_if_supported()
-    res = _libtaos.tmq_commit(tmq, offset, _async)
+    res = _libtaos.tmq_commit_sync(tmq, offset)
     if res != 0:
-        raise TmqError(msg="failed on tmq_commit()", errno=res)
+        raise TmqError(msg="failed on tmq_commit_sync()", errno=res)
+
 
 try:
     _libtaos.tmq_get_topic_name.argtypes = (c_void_p,)
@@ -1157,48 +1196,56 @@ try:
 except Exception as err:
     _UNSUPPORTED["tmq_get_topic_name"] = err
 
+
 def tmq_get_topic_name(res):
-    # type (c_void_p,) -> string
+    # type: (c_void_p) -> str
     _check_if_supported()
     return _libtaos.tmq_get_topic_name(res).decode("utf-8")
 
+
 try:
     _libtaos.tmq_get_vgroup_id.argtypes = (c_void_p,)
     _libtaos.tmq_get_vgroup_id.restype = c_int
 except Exception as err:
     _UNSUPPORTED["tmq_get_vgroup_id"] = err
 
+
 def tmq_get_vgroup_id(res):
-    # type (c_void_p,) -> int
+    # type: (c_void_p) -> int
     _check_if_supported()
     return _libtaos.tmq_get_vgroup_id(res)
 
+
 try:
     _libtaos.tmq_get_table_name.argtypes = (c_void_p,)
     _libtaos.tmq_get_table_name.restype = c_char_p
 except Exception as err:
     _UNSUPPORTED["tmq_get_table_name"] = err
 
+
 def tmq_get_table_name(res):
-    # type (c_void_p,) -> string
+    # type: (c_void_p) -> str
     _check_if_supported()
     tb_name = _libtaos.tmq_get_table_name(res)
     if tb_name:
         return tb_name.decode("utf-8")
-    else:
-        print("change msg.with.table.name to true in tmq config")
+    # else:
+    #     print("change msg.with.table.name to true in tmq config")
 
-try:        
+
+try:
     _libtaos.tmq_get_db_name.argtypes = (c_void_p,)
     _libtaos.tmq_get_db_name.restype = c_char_p
 except Exception as err:
     _UNSUPPORTED["tmq_get_db_name"] = err
 
+
 def tmq_get_db_name(res):
-    # type (c_void_p,) -> string
+    # type: (c_void_p) -> str
     _check_if_supported()
     return _libtaos.tmq_get_db_name(res).decode("utf-8")
 
+
 def _check_if_supported(func=None):
     if not func:
         func = inspect.stack()[1][3]
@@ -1213,6 +1260,36 @@ def unsupported_methods():
         print("unsupported %s: %s", m, e)
 
 
+try:
+    _libtaos.taos_get_table_vgId.argstype = (c_void_p, c_char_p, c_char_p, POINTER(c_int))
+    _libtaos.taos_get_table_vgId.restype = c_int
+except Exception as err:
+    _UNSUPPORTED["taos_get_table_vgId"] = err
+
+
+def taos_get_table_vgId(conn, db, table):
+    # type: (c_void_p, str, str) -> int
+    _check_if_supported()
+    vg_id = c_int()
+    code = _libtaos.taos_get_table_vgId(conn, c_char_p(db.encode('utf-8')), c_char_p(table.encode('utf-8')),
+                                        ctypes.byref(vg_id))
+    if code != 0:
+        raise InternalError(taos_errstr(c_void_p(None)))
+    return vg_id.value
+
+
+try:
+    _libtaos.tmq_get_res_type.argstype = (c_void_p,)
+    _libtaos.tmq_get_res_type.restype = c_int
+except Exception as err:
+    _UNSUPPORTED["tmq_get_res_type"] = err
+
+
+def tmq_get_res_type(message):
+    # type: (c_void_p) -> int
+    return _libtaos.tmq_get_res_type(message)
+
+
 class CTaosInterface(object):
     def __init__(self, config=None, tz=None):
         """
