@@ -1,13 +1,12 @@
 # encoding:UTF-8
 import ctypes
-import math
+from ctypes import *
+from datetime import datetime, timedelta
+
 import pytz
 
-from datetime import datetime, timedelta
-from ctypes import *
-
-from .constants import FieldType
-from .error import *
+from taos.constants import FieldType
+from taos.error import DatabaseError
 
 _priv_tz = None
 _utc_tz = pytz.timezone("UTC")
@@ -98,7 +97,7 @@ def _crow_smallint_to_python(data, is_null, num_of_rows, nbytes=None, precision=
 
 
 def _crow_smallint_unsigned_to_python(
-    data, is_null, num_of_rows, nbytes=None, precision=FieldType.C_TIMESTAMP_UNKNOWN
+        data, is_null, num_of_rows, nbytes=None, precision=FieldType.C_TIMESTAMP_UNKNOWN
 ):
     """Function to convert C unsigned smallint row to python row."""
     return [
@@ -199,7 +198,7 @@ def _crow_binary_to_python_block(data, is_null, num_of_rows, nbytes=None, precis
         if is_null[i]:
             res.append(None)
         else:
-            rbyte = ctypes.cast(data + nbytes * i, ctypes.POINTER(ctypes.c_short))[:1].pop()
+            rbyte = ctypes.cast(data + nbytes * i, ctypes.POINTER(ctypes.c_uint16))[:1].pop()
             chars = ctypes.cast(c_char_p(data + nbytes * i + 2), ctypes.POINTER(c_char * rbyte))
             buffer = create_string_buffer(rbyte + 1)
             buffer[:rbyte] = chars[0][:rbyte]
@@ -215,7 +214,7 @@ def _crow_nchar_to_python_block(data, is_null, num_of_rows, nbytes=None, precisi
         if is_null[i]:
             res.append(None)
         else:
-            rbyte = ctypes.cast(data + nbytes * i, ctypes.POINTER(ctypes.c_short))[:1].pop()
+            rbyte = ctypes.cast(data + nbytes * i, ctypes.POINTER(ctypes.c_uint16))[:1].pop()
             chars = ctypes.cast(c_char_p(data + nbytes * i + 2), ctypes.POINTER(c_char * rbyte))
             buffer = create_string_buffer(rbyte + 1)
             buffer[:rbyte] = chars[0][:rbyte]
@@ -259,6 +258,7 @@ CONVERT_FUNC_BLOCK = {
     FieldType.C_JSON: _crow_nchar_to_python_block,
 }
 
+
 # Corresponding TAOS_FIELD structure in C
 
 
