@@ -18,20 +18,6 @@ TYPES_MAP = {
     "binary": sqltypes.String,
 }
 
-class AlchemyWsConnection:
-    threadsafety = 1
-    paramstyle = "pyformat"
-
-    def connect(self, **kwargs):
-        host = kwargs["host"] if "host" in kwargs else "localhost"
-        port = kwargs["port"] if "port" in kwargs else "6041"
-        user = kwargs["user"] if "user" in kwargs else "root"
-        password = kwargs["password"] if "password" in kwargs else "taosdata"
-        token = kwargs["token"] if "token" in kwargs else ""
-        url = f"ws://{user}:{password}@{host}:{port}"
-        import taosws
-        return taosws.connect(url)
-
 
 class TaosWsDialect(default.DefaultDialect):
     name = "taosws"
@@ -43,11 +29,14 @@ class TaosWsDialect(default.DefaultDialect):
         pass
 
     def _get_server_version_info(self, connection):
-        return tuple("any")
+        cursor = connection.execute("select server_version()")
+        return cursor.fetchone()
 
     @classmethod
     def dbapi(cls):
-        return AlchemyWsConnection()
+        import taosws
+
+        return taosws
 
     def has_schema(self, connection, schema):
         return False
@@ -77,6 +66,21 @@ class TaosWsDialect(default.DefaultDialect):
     def _resolve_type(self, type_):
         return TYPES_MAP.get(type_, sqltypes.UserDefinedType)
 
+
+class AlchemyTaosConnection:
+    paramstyle = "pyformat"
+
+    def connect(self, **kwargs):
+        host = kwargs["host"] if "host" in kwargs else "localhost"
+        port = kwargs["port"] if "port" in kwargs else "6030"
+        user = kwargs["username"] if "username" in kwargs else "root"
+        password = kwargs["password"] if "password" in kwargs else "taosdata"
+
+        import taos
+
+        return taos.connect(host=host, user=user, password=password, port=int(port))
+
+
 class TaosDialect(default.DefaultDialect):
     name = "taos"
     driver = "taos"
@@ -91,9 +95,7 @@ class TaosDialect(default.DefaultDialect):
 
     @classmethod
     def dbapi(cls):
-        import taos
-
-        return taos
+        return AlchemyTaosConnection()
 
     def has_schema(self, connection, schema):
         return False
